==> haskell-binary-tagged-0.1.4.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.2
id: binary-tagged-0.1.4.2-F9knynIYW8VDcTlYQOqSR4
key: binary-tagged-0.1.4.2-F9knynIYW8VDcTlYQOqSR4
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: c60dd47d1be6f63754c86e6e2174b14e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/binary-tagged-0.1.4.2
hs-libraries: HSbinary-tagged-0.1.4.2-F9knynIYW8VDcTlYQOqSR4
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM array-0.5.1.1 base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS binary-0.8.3.0
    bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.3.0-4LnlPExx4v7Lf51hjx2oHe
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.1.4.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.2
id: binary-tagged-0.1.4.2-1O2piKnaZRG3wJzHfDXO9o
key: binary-tagged-0.1.4.2-1O2piKnaZRG3wJzHfDXO9o
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: 60d89a910bd24fe3634ce4e85851b37b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/binary-tagged-0.1.4.2
hs-libraries: HSbinary-tagged-0.1.4.2-1O2piKnaZRG3wJzHfDXO9o
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M array-0.5.1.1 base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS binary-0.8.3.0
    bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.3.0-4LnlPExx4v7Lf51hjx2oHe
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
